@@ -46,7 +46,7 @@ class GetQuotaRootJobPrivate;
  *
  * This job requires that the server supports the QUOTA
  * capability, defined in
- * <a href="http://www.apps.ietf.org/rfc/rfc2087.html">RFC 2087</a>.
+ * <a href="https://tools.ietf.org/html/rfc2087">RFC 2087</a>.
  */
 class KIMAP_EXPORT GetQuotaRootJob : public QuotaJobBase
 {
@@ -68,12 +68,12 @@ public:
     /**
      * The mailbox that the quota roots will be fetched for.
      */
-    QString mailBox() const;
+    Q_REQUIRED_RESULT QString mailBox() const;
 
     /**
      * The quota roots for the mailbox.
      */
-    QList<QByteArray> roots() const;
+    Q_REQUIRED_RESULT QList<QByteArray> roots() const;
     /**
      * Get the current usage for a resource.
      *
@@ -87,7 +87,7 @@ public:
      *          if the usage is unknown or there is no
      *          limit on the resource
      */
-    qint64 usage(const QByteArray &root, const QByteArray &resource) const;
+    Q_REQUIRED_RESULT qint64 usage(const QByteArray &root, const QByteArray &resource) const;
     /**
      * Get the current limit for a resource.
      *
@@ -97,7 +97,7 @@ public:
      *          if the limit is unknown or there is no
      *          limit on the resource
      */
-    qint64 limit(const QByteArray &root, const QByteArray &resource) const;
+    Q_REQUIRED_RESULT qint64 limit(const QByteArray &root, const QByteArray &resource) const;
 
     /**
      * Get a map containing all resource usage figures for a quota root.
@@ -105,14 +105,14 @@ public:
      * @param root  the quota root to get resource usage figures for
      * @return  a map from resource names to usage figures
      */
-    QMap<QByteArray, qint64> allUsages(const QByteArray &root) const;
+    Q_REQUIRED_RESULT QMap<QByteArray, qint64> allUsages(const QByteArray &root) const;
     /**
      * Get a map containing all resource limits for a quota root.
      *
      * @param root  the quota root to get resource limits for
      * @return  a map from resource names to limits
      */
-    QMap<QByteArray, qint64> allLimits(const QByteArray &root) const;
+    Q_REQUIRED_RESULT QMap<QByteArray, qint64> allLimits(const QByteArray &root) const;
 
 protected:
     void doStart() override;
