@@ -19,11 +19,11 @@
 
 #include "idlejob.h"
 
-#include <QtCore/QTimer>
+#include <QTimer>
 #include <KLocalizedString>
 
 #include "job_p.h"
-#include "message_p.h"
+#include "response_p.h"
 #include "session_p.h"
 
 namespace KIMAP
@@ -103,7 +103,7 @@ void IdleJob::doStart()
     d->tags << d->sessionInternal()->sendCommand("IDLE");
 }
 
-void IdleJob::handleResponse(const Message &response)
+void IdleJob::handleResponse(const Response &response)
 {
     Q_D(IdleJob);
 
@@ -118,24 +118,25 @@ void IdleJob::handleResponse(const Message &response)
     }
 
     if (handleErrorReplies(response) == NotHandled) {
-        if (response.content.size() > 0 && response.content[0].toString() == "+") {
+        if (!response.content.isEmpty() && response.content[0].toString() == "+") {
             // Got the continuation all is fine
             return;
 
         } else if (response.content.size() > 2) {
-            if (response.content[2].toString() == "EXISTS") {
+            const QByteArray ba = response.content[2].toString();
+            if (ba == "EXISTS") {
                 if (d->messageCount >= 0) {
                     d->emitStats();
                 }
 
                 d->messageCount = response.content[1].toString().toInt();
-            } else if (response.content[2].toString() == "RECENT") {
+            } else if (ba == "RECENT") {
                 if (d->recentCount >= 0) {
                     d->emitStats();
                 }
 
                 d->recentCount = response.content[1].toString().toInt();
-            } else if (response.content[2].toString() == "FETCH") {
+            } else if (ba == "FETCH") {
                 const qint64 uid = response.content[1].toString().toLongLong();
                 Q_EMIT mailBoxMessageFlagsChanged(this, uid);
             }
