@@ -25,9 +25,9 @@
 
 #include <exception>
 
-#include <QtCore/QByteArray>
-#include <QtCore/QList>
-#include <QtCore/QString>
+#include <QByteArray>
+#include <QList>
+#include <QString>
 
 class QIODevice;
 
@@ -42,7 +42,7 @@ public:
     explicit ImapParserException(const QString &what) throw() : mWhat(what.toUtf8()) {}
     ImapParserException(const ImapParserException &other) throw() : std::exception(other), mWhat(other.what()) {}
     virtual ~ImapParserException() throw() {}
-    const char *what() const throw() Q_DECL_OVERRIDE
+    const char *what() const throw() override
     {
         return mWhat.constData();
     }
@@ -93,7 +93,7 @@ public:
      * @param ok true if the data found was a number
      * @return the number
      */
-    qint64 readNumber(bool *ok = Q_NULLPTR);
+    qint64 readNumber(bool *ok = nullptr);
 
     /**
      * Check if the next data is a string or not. This call might block.
@@ -204,11 +204,11 @@ private:
      */
     void trimBuffer();
 
-    QIODevice *m_socket;
-    bool m_isServerModeEnabled;
+    QIODevice *m_socket = nullptr;
+    bool m_isServerModeEnabled = false;
     QByteArray m_data;
-    int m_position;
-    qint64 m_literalSize;
+    int m_position = -1;
+    qint64 m_literalSize = -1;
 };
 
 }
