@@ -28,7 +28,7 @@ namespace KIMAP
 {
 
 class Session;
-struct Message;
+struct Response;
 class ListRightsJobPrivate;
 
 /**
@@ -44,7 +44,7 @@ class ListRightsJobPrivate;
  *
  * This job requires that the server supports the ACL
  * capability, defined in
- * <a href="http://www.apps.ietf.org/rfc/rfc4314.html">RFC 4314</a>.
+ * <a href="https://tools.ietf.org/html/rfc4314">RFC 4314</a>.
  */
 class KIMAP_EXPORT ListRightsJob : public AclJobBase
 {
@@ -55,7 +55,7 @@ class KIMAP_EXPORT ListRightsJob : public AclJobBase
 
 public:
     explicit ListRightsJob(Session *session);
-    virtual ~ListRightsJob();
+    ~ListRightsJob() override;
 
     /**
      * Sets the identifier that should be looked up
@@ -81,7 +81,7 @@ public:
     /**
      * The identifier that will be looked up
      */
-    QByteArray identifier();
+    Q_REQUIRED_RESULT QByteArray identifier();
 
     /**
      * The rights that will always be assigned to the identifier,
@@ -90,7 +90,7 @@ public:
      * For example, under the UNIX permission model, the owner
      * of a mailbox will always have the Acl::Admin right.
      */
-    Acl::Rights defaultRights();
+    Q_REQUIRED_RESULT Acl::Rights defaultRights();
 
     /**
      * The rights it is possible to assign to the identifier.
@@ -109,11 +109,11 @@ public:
      * - Acl::DeleteMessage
      * - Acl::Expunge
      */
-    QList<Acl::Rights> possibleRights();
+    Q_REQUIRED_RESULT QList<Acl::Rights> possibleRights();
 
 protected:
-    void doStart() Q_DECL_OVERRIDE;
-    void handleResponse(const Message &response) Q_DECL_OVERRIDE;
+    void doStart() override;
+    void handleResponse(const Response &response) override;
 
 };
 
