@@ -42,11 +42,6 @@ class KIMAP_EXPORT LoginJob : public Job
 public:
     enum EncryptionMode {
         Unencrypted = 0,
-        TlsV1,  ///< @deprecated Use EncryptionMode::STARTTLS instead
-        SslV2,  ///< @deprecated Use EncryptionMode::SSLorTLS instead
-        SslV3, ///< @deprecated Use EncryptionMode::SSLorTLS instead
-        SslV3_1, ///< @deprecated Use EncryptionMode::SSLorTLS instead
-        AnySslVersion, ///< @deprecated Use EncryptionMode::SSLorTLS instead
         SSLorTLS, /*!< Use SSL/TLS encryption, KIMAP will automatically negoatiate
                        the best supported encryption protocol. */
         STARTTLS  /*!< Use STARTTLS to upgrade an initially plaintext connection to
@@ -73,14 +68,14 @@ public:
     explicit LoginJob(Session *session);
     ~LoginJob() override;
 
-    QString userName() const;
+    Q_REQUIRED_RESULT QString userName() const;
     void setUserName(const QString &userName);
 
     /**
      * Get the authorization identity.
      * @since 4.10
      */
-    QString authorizationName() const;
+    Q_REQUIRED_RESULT QString authorizationName() const;
 
     /**
      * Set the authorization identity.
@@ -95,7 +90,7 @@ public:
      */
     void setAuthorizationName(const QString &authorizationName);
 
-    QString password() const;
+    Q_REQUIRED_RESULT QString password() const;
     void setPassword(const QString &password);
 
     /**
@@ -107,7 +102,7 @@ public:
      * implementation-dependent.
      * @since 4.7
      */
-    QString serverGreeting() const;
+    Q_REQUIRED_RESULT QString serverGreeting() const;
 
     /**
      * Set the encryption mode for the connection. In case an encryption mode is set, the caller
@@ -121,7 +116,7 @@ public:
       Get the encryption mode.
       @return the currently active encryption mode
     */
-    EncryptionMode encryptionMode();
+    Q_REQUIRED_RESULT EncryptionMode encryptionMode();
 
     void setAuthenticationMode(AuthenticationMode mode);
 
