@@ -22,20 +22,37 @@
 #include <KLocalizedString>
 #include "kimap_debug.h"
 
-#include <QtCore/QDate>
+#include <QDate>
 
 #include "job_p.h"
-#include "message_p.h"
+#include "response_p.h"
 #include "session_p.h"
 #include "imapset.h"
 
 namespace KIMAP
 {
 
-class Term::Private
+class Term::Private : public QSharedData
 {
 public:
-    Private(): isFuzzy(false), isNegated(false), isNull(false) {}
+    Private(): QSharedData(), isFuzzy(false), isNegated(false), isNull(false) {}
+    Private(const Private &other)
+        : QSharedData(other)
+        , command(other.command)
+        , isFuzzy(other.isFuzzy)
+        , isNegated(other.isNegated)
+        , isNull(other.isNull)
+    {}
+
+    Private &operator=(const Private &other)
+    {
+        command = other.command;
+        isFuzzy = other.isFuzzy;
+        isNegated = other.isNegated;
+        isNull = other.isNull;
+        return *this;
+    }
+
     QByteArray command;
     bool isFuzzy;
     bool isNegated;
@@ -63,7 +80,7 @@ Term::Term(Term::Relation relation, const QVector<Term> &subterms)
                 d->command += subterms.at(1).serialize();
             }
         } else {
-            Q_FOREACH (const Term &t, subterms) {
+            for (const Term &t : subterms) {
                 d->command += t.serialize() + ' ';
             }
             if (!subterms.isEmpty()) {
@@ -223,6 +240,10 @@ Term::Term(const Term &other)
     *d = *other.d;
 }
 
+Term::~Term()
+{
+}
+
 Term &Term::operator=(const Term &other)
 {
     *d = *other.d;
@@ -381,7 +402,8 @@ void SearchJob::doStart()
         }
 
         if (d->logic == SearchJob::And) {
-            for (int i = 0; i < d->criterias.size(); i++) {
+            const int numberCriterias(d->criterias.size());
+            for (int i = 0; i < numberCriterias; i++) {
                 const QByteArray key = d->criterias.at(i);
                 if (i > 0) {
                     searchKey += ' ';
@@ -389,7 +411,8 @@ void SearchJob::doStart()
                 searchKey += key;
             }
         } else {
-            for (int i = 0; i < d->criterias.size(); i++) {
+            const int numberCriterias(d->criterias.size());
+            for (int i = 0; i < numberCriterias; i++) {
                 const QByteArray key = d->criterias.at(i);
                 if (i > 0) {
                     searchKey += ' ';
@@ -407,7 +430,7 @@ void SearchJob::doStart()
     d->tags << d->sessionInternal()->sendCommand(command, searchKey);
 }
 
-void SearchJob::handleResponse(const Message &response)
+void SearchJob::handleResponse(const Response &response)
 {
     Q_D(SearchJob);
 
