@@ -22,7 +22,7 @@
 
 #include "kimap_export.h"
 
-#include <QtCore/QObject>
+#include <QObject>
 
 #include "sessionuiproxy.h"
 
@@ -31,7 +31,7 @@ namespace KIMAP
 
 class SessionPrivate;
 class JobPrivate;
-struct Message;
+struct Response;
 
 class KIMAP_EXPORT Session : public QObject
 {
@@ -45,9 +45,9 @@ public:
     Session(const QString &hostName, quint16 port, QObject *parent = nullptr);
     ~Session();
 
-    QString hostName() const;
-    quint16 port() const;
-    State state() const;
+    Q_REQUIRED_RESULT QString hostName() const;
+    Q_REQUIRED_RESULT quint16 port() const;
+    Q_REQUIRED_RESULT State state() const;
 
     /**
      * Returns the name that has been set with LoginJob::setUserName()
@@ -55,9 +55,9 @@ public:
      * @note If the Session was pre-authenticated, userName() will return an empty string
      * @since 4.7
      */
-    QString userName() const;
+    Q_REQUIRED_RESULT QString userName() const;
 
-    QByteArray serverGreeting() const;
+    Q_REQUIRED_RESULT QByteArray serverGreeting() const;
 
     /**
      * Sets an ui proxy that displays the error messages and waits for user feedback.
@@ -83,15 +83,27 @@ public:
      * Returns the session timeout.
      * @since 4.12
      */
-    int timeout() const;
+    Q_REQUIRED_RESULT int timeout() const;
 
     /**
      * Returns the currently selected mailbox.
      * @since 4.5
      */
-    QString selectedMailBox() const;
+    Q_REQUIRED_RESULT QString selectedMailBox() const;
 
-    int jobQueueSize() const;
+   /**
+    * Sets whether the IMAP network connection should use the system proxy settings.
+    *
+    * @param useProxy @c true if the proxy is to be used
+    * The default is to not use the proxy.
+    * @since 5.11.41
+    *
+    * @note If the session is currently connected to the IMAP server, calling this
+    * function will disconnect and reconnect to it with the changed proxy setting.
+    */
+    void setUseNetworkProxy(bool useProxy);
+
+    Q_REQUIRED_RESULT int jobQueueSize() const;
 
     void close();
 
@@ -99,18 +111,11 @@ Q_SIGNALS:
     void jobQueueSizeChanged(int queueSize);
 
     /**
-      @deprecated
-      Emitted when we loose a previously established connection
+      Emitted when we lose a previously established connection
 
       Likely reasons: server closed the connection, loss of internet connectivity, etc...
-
-      For historical reasons, this signal is also emitted in the event of a failed connection, but
-      you should not rely on this behavior.
-
-      New implementations should use connectionFailed() to detect a failure to connect to the host,
-      and stateChanged() to detect a loss of connectivity.
     */
-    KIMAP_DEPRECATED void connectionLost();
+    void connectionLost();
 
     /**
       Emitted when the Session couldn't connect to the host.
@@ -128,8 +133,7 @@ Q_SIGNALS:
     /**
       Emitted when the session's state changes.
 
-      You can use this signal to detect a connection loss (ie: stateChanged is emitted with newState
-      == KIMAP::Session::Disconnected)
+      Not very useful after all... :-)
 
       If you want to receive the stateChanged arguments in your slot, you must register the State
       enum with @c Q_DECLARE_METATYPE(KIMAP::Session::State) and @c qRegisterMetaType<KIMAP::Session::State>();
